%global srcname lazr.config
%global pkgname lazr-config
%global summary Create configuration schemas, and process and validate configurations
%global _description \
The LAZR config system is typically used to manage process configuration.      \
Process configuration is for saying how things change when we run systems on   \
different machines, or under different circumstances.                          \
\
This system uses ini-like file format of section, keys, and values. The config \
file supports inheritance to minimize duplication of information across files. \
The format supports schema validation.

# EPEL7 support: default Python is Python 2, and Python2 packages prefix
# is unversioned.
%if 0%{?rhel} && 0%{?rhel} <= 7
%global py2_namespace python
%else
%global py2_namespace python2
%endif


Name:           python-%{pkgname}
Version:        2.1
Release:        1%{?dist}
Summary:        %{summary}

License:        LGPLv3
URL:            https://launchpad.net/lazr.config
Source0:        https://files.pythonhosted.org/packages/source/l/%{srcname}/%{srcname}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  %{py2_namespace}-devel
BuildRequires:  %{py2_namespace}-setuptools
BuildRequires:  %{py2_namespace}-zope-interface
BuildRequires:  %{py2_namespace}-nose
BuildRequires:  %{py2_namespace}-lazr-delegates
# Python3
BuildRequires: python3-pkgversion-macros
BuildRequires: python%{python3_pkgversion}-devel
BuildRequires: python%{python3_pkgversion}-setuptools
BuildRequires: python%{python3_pkgversion}-zope-interface
BuildRequires: python%{python3_pkgversion}-nose
BuildRequires: python%{python3_pkgversion}-lazr-delegates
%if 0%{?with_python3_other}
BuildRequires: python%{python3_other_pkgversion}-devel
BuildRequires: python%{python3_other_pkgversion}-setuptools
BuildRequires: python%{python3_other_pkgversion}-zope-interface
BuildRequires: python%{python3_other_pkgversion}-nose
BuildRequires: python%{python3_other_pkgversion}-lazr-delegates
%endif


%description %{_description}


%if %{py2_namespace} != python
%package -n %{py2_namespace}-%{pkgname}
Summary:        %{summary}
%{?python_provide:%python_provide python2-%{pkgname}}
Requires:       %{py2_namespace}-setuptools
Requires:       %{py2_namespace}-zope-interface
Requires:       %{py2_namespace}-lazr-delegates

%description -n %{py2_namespace}-%{pkgname} %{_description}
%endif


%package -n python%{python3_pkgversion}-%{pkgname}
Summary:        %{summary}
%{?python_provide:%python_provide python%{python3_pkgversion}-%{pkgname}}
Requires:       python%{python3_pkgversion}-setuptools
Requires:       python%{python3_pkgversion}-zope-interface
Requires:       python%{python3_pkgversion}-lazr-delegates

%description -n python%{python3_pkgversion}-%{pkgname} %{_description}


%if 0%{?with_python3_other}
%package -n python%{python3_other_pkgversion}-%{pkgname}
Summary:        %{summary}
%{?python_provide:%python_provide python%{python3_other_pkgversion}-%{pkgname}}
Requires:       python%{python3_other_pkgversion}-setuptools
Requires:       python%{python3_other_pkgversion}-zope-interface
Requires:       python%{python3_other_pkgversion}-lazr-delegates

%description -n python%{python3_other_pkgversion}-%{pkgname} %{_description}
%endif


%prep
%autosetup -n %{srcname}-%{version}

sed -i -e '/^with-coverage/d;/^pdb /d;/^cover-package/d' setup.cfg


%build
%py2_build
%py3_build
%if 0%{?with_python3_other}
%py3_other_build
%endif


%install
%py2_install
%py3_install
%if 0%{?with_python3_other}
%py3_other_install
%endif


%check
%{__python2} setup.py nosetests
# In Python3, namespace packages don't have an __init__.py file in the parent
# dir. Keeping it would shadow the lazr.delegates module.
rm lazr/__init__.py*
sed -i -e 's/^\(\s*namespace_packages=.*\)/#\1/' setup.py
%{__python3} setup.py nosetests
%if 0%{?with_python3_other}
%{__python3_other} setup.py nosetests
%endif


%files -n %{py2_namespace}-%{pkgname}
%license COPYING.txt
%doc README.rst HACKING.rst
%{python2_sitelib}/lazr/
%{python2_sitelib}/%{srcname}-%{version}*-py%{python2_version}.egg-info/
%{python2_sitelib}/%{srcname}-%{version}*-py%{python2_version}-nspkg.pth

%files -n python%{python3_pkgversion}-%{pkgname}
%license COPYING.txt
%doc README.rst HACKING.rst
%{python3_sitelib}/lazr/
%{python3_sitelib}/%{srcname}-%{version}*-py%{python3_version}.egg-info/
%{python3_sitelib}/%{srcname}-%{version}*-py%{python3_version}-nspkg.pth

%if 0%{?with_python3_other}
%files -n python%{python3_other_pkgversion}-%{pkgname}
%license COPYING.txt
%doc README.rst HACKING.rst
%{python3_other_sitelib}/lazr/
%{python3_other_sitelib}/%{srcname}-%{version}*-py%{python3_other_version}.egg-info/
%{python3_other_sitelib}/%{srcname}-%{version}*-py%{python3_other_version}-nspkg.pth
%endif


%changelog
* Wed Sep 14 2016 Aurelien Bompard <abompard@fedoraproject.org> - 2.1-1
- Initial package.
